@@ -117,6 +117,14 @@ pub fn handle_service(service: Service, base_path: &Path, _force: bool) -> Resul
             instance.as_str()
         );
         let location = Path::new(&location_str);
+
+        std::fs::create_dir_all(
+            Path::new(&location_str)
+                .parent()
+                .with_context(|| format!("Could not get path '{}'", &location_str))?,
+        )
+        .with_context(|| format!("Could not create path '{}'", &location_str))?;
+
         // TODO: check if already exists
         // stop, write, daemon-reload and restart if exists
         // if not exists, write and enable
